=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2005-10-03 03:30:02 +0000
+++ bzrlib/delta.py	2005-10-03 01:42:16 +0000
@@ -14,7 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from bzrlib.inventory import InventoryEntry
 from bzrlib.trace import mutter
 
 class TreeDelta(object):
@@ -172,7 +171,7 @@
             kind = old_ie.kind
             assert kind == new_ie.kind
             
-            assert kind in InventoryEntry.known_kinds, \
+            assert kind in ('file', 'directory', 'symlink', 'root_directory'), \
                    'invalid file kind %r' % kind
 
             if kind == 'root_directory':
@@ -183,13 +182,28 @@
                     and not is_inside_any(specific_files, new_inv.id2path(file_id))):
                     continue
 
-            # temporary hack until all entries are populated before clients 
-            # get them
-            old_path = old_inv.id2path(file_id)
-            new_path = new_inv.id2path(file_id)
-            old_ie._read_tree_state(old_path, old_tree)
-            new_ie._read_tree_state(new_path, new_tree)
-            text_modified, meta_modified = new_ie.detect_changes(old_ie)
+            if kind == 'file':
+                old_sha1 = old_tree.get_file_sha1(file_id)
+                new_sha1 = new_tree.get_file_sha1(file_id)
+                text_modified = (old_sha1 != new_sha1)
+                old_exec = old_tree.is_executable(file_id)
+                new_exec = new_tree.is_executable(file_id)
+                meta_modified = (old_exec != new_exec)
+            elif kind == 'symlink':
+                t1 = old_tree.get_symlink_target(file_id)
+                t2 = new_tree.get_symlink_target(file_id)
+                if t1 != t2:
+                    mutter("    symlink target changed")
+                    # FIXME: which should we use ?
+                    text_modified = True
+                    meta_modified = False
+                else:
+                    text_modified = False
+                    meta_modified = False
+            else:
+                ## mutter("no text to check for %r %r" % (file_id, kind))
+                text_modified = False
+                meta_modified = False
 
             # TODO: Can possibly avoid calculating path strings if the
             # two files are unchanged and their names and parents are
@@ -198,15 +212,15 @@
             
             if (old_ie.name != new_ie.name
                 or old_ie.parent_id != new_ie.parent_id):
-                delta.renamed.append((old_path,
-                                      new_path,
+                delta.renamed.append((old_inv.id2path(file_id),
+                                      new_inv.id2path(file_id),
                                       file_id, kind,
                                       text_modified, meta_modified))
             elif text_modified or meta_modified:
-                delta.modified.append((new_path, file_id, kind,
+                delta.modified.append((new_inv.id2path(file_id), file_id, kind,
                                        text_modified, meta_modified))
             elif want_unchanged:
-                delta.unchanged.append((new_path, file_id, kind))
+                delta.unchanged.append((new_inv.id2path(file_id), file_id, kind))
         else:
             kind = old_inv.get_file_kind(file_id)
             if kind == 'root_directory':

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2005-10-03 05:16:47 +0000
+++ bzrlib/diff.py	2005-10-03 01:42:16 +0000
@@ -209,13 +209,20 @@
 
     for path, file_id, kind in delta.removed:
         print >>to_file, '=== removed %s %r' % (kind, path)
-        old_tree.inventory[file_id].diff(diff_file, old_label + path, old_tree,
-                                         DEVNULL, None, None, to_file)
+        if kind == 'file':
+            diff_file(old_label + path,
+                      old_tree.get_file(file_id).readlines(),
+                      DEVNULL, 
+                      [],
+                      to_file)
     for path, file_id, kind in delta.added:
         print >>to_file, '=== added %s %r' % (kind, path)
-        new_tree.inventory[file_id].diff(diff_file, new_label + path, new_tree,
-                                         DEVNULL, None, None, to_file, 
-                                         reverse=True)
+        if kind == 'file':
+            diff_file(DEVNULL,
+                      [],
+                      new_label + path,
+                      new_tree.get_file(file_id).readlines(),
+                      to_file)
     for (old_path, new_path, file_id, kind,
          text_modified, meta_modified) in delta.renamed:
         prop_str = get_prop_change(meta_modified)
@@ -244,8 +251,16 @@
                                 new_label, new_path, new_tree, text_modified,
                                 kind, to_file, diff_file):
     if text_modified:
-        new_entry = new_tree.inventory[file_id]
-        old_tree.inventory[file_id].diff(diff_file,
-                                         old_label + old_path, old_tree,
-                                         new_label + new_path, new_entry, 
-                                         new_tree, to_file)
+        if kind == 'file':
+            diff_file(old_label + old_path,
+                      old_tree.get_file(file_id).readlines(),
+                      new_label + new_path,
+                      new_tree.get_file(file_id).readlines(),
+                      to_file)
+        elif kind == 'symlink':
+            _diff_symlink(old_tree, new_tree, file_id, to_file)
+            
+def _diff_symlink(old_tree, new_tree, file_id, to_file):
+    t1 = old_tree.get_symlink_target(file_id)
+    t2 = new_tree.get_symlink_target(file_id)
+    print >>to_file, '=== target changed %r => %r' % (t1, t2)

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2005-10-03 05:27:22 +0000
+++ bzrlib/fetch.py	2005-10-02 23:17:00 +0000
@@ -210,7 +210,7 @@
         # in memory until everything's done?  But this way is nicer
         # if it's interrupted.
         for path, ie in inv.iter_entries():
-            if not ie.has_text():
+            if ie.kind != 'file':
                 continue
             if ie.revision != rev_id:
                 continue

=== modified file 'bzrlib/inventory.py'
--- bzrlib/inventory.py	2005-10-03 05:54:35 +0000
+++ bzrlib/inventory.py	2005-10-03 02:54:29 +0000
@@ -31,14 +31,12 @@
 import os.path
 import re
 import sys
-import tarfile
 import types
 
 import bzrlib
 from bzrlib.errors import BzrError, BzrCheckError
 
-from bzrlib.osutils import (pumpfile, quotefn, splitpath, joinpath,
-                            appendpath, sha_strings)
+from bzrlib.osutils import quotefn, splitpath, joinpath, appendpath, sha_strings
 from bzrlib.trace import mutter
 from bzrlib.errors import NotVersionedError
 
@@ -124,102 +122,6 @@
     def _add_text_to_weave(self, new_lines, parents, weave_store):
         weave_store.add_text(self.file_id, self.revision, new_lines, parents)
 
-    def detect_changes(self, old_entry):
-        """Return a (text_modified, meta_modified) from this to old_entry.
-        
-        _read_tree_state must have been called on self and old_entry prior to 
-        calling detect_changes.
-        """
-        if self.kind == 'file':
-            assert self.text_sha1 != None
-            assert old_entry.text_sha1 != None
-            text_modified = (self.text_sha1 != old_entry.text_sha1)
-            meta_modified = (self.executable != old_entry.executable)
-        elif self.kind == 'symlink':
-            # FIXME: which _modified field should we use ? RBC 20051003
-            text_modified = (self.symlink_target != old_entry.symlink_target)
-            if text_modified:
-                mutter("    symlink target changed")
-            meta_modified = False
-        else:
-            text_modified = False
-            meta_modified = False
-        return text_modified, meta_modified
-
-    def diff(self, text_diff, from_label, tree, to_label, to_entry, to_tree,
-             output_to, reverse=False):
-        """Perform a diff from this to to_entry.
-
-        text_diff will be used for textual difference calculation.
-        """
-        self._read_tree_state(tree.id2path(self.file_id), tree)
-        if to_entry:
-            # cannot diff from one kind to another - you must do a removal
-            # and an addif they do not match.
-            assert self.kind == to_entry.kind
-            to_entry._read_tree_state(to_tree.id2path(to_entry.file_id),
-                                      to_tree)
-        if self.kind == 'file':
-            from_text = tree.get_file(self.file_id).readlines()
-            if to_entry:
-                to_text = to_tree.get_file(to_entry.file_id).readlines()
-            else:
-                to_text = []
-            if not reverse:
-                text_diff(from_label, from_text,
-                          to_label, to_text, output_to)
-            else:
-                text_diff(to_label, to_text,
-                          from_label, from_text, output_to)
-        elif self.kind == 'symlink':
-            from_text = self.symlink_target
-            if to_entry is not None:
-                to_text = to_entry.symlink_target
-                if reverse:
-                    temp = from_text
-                    from_text = to_text
-                    to_text = temp
-                print >>output_to, '=== target changed %r => %r' % (from_text, to_text)
-            else:
-                if not reverse:
-                    print >>output_to, '=== target was %r' % self.symlink_target
-                else:
-                    print >>output_to, '=== target is %r' % self.symlink_target
-
-    def get_tar_item(self, root, dp, now, tree):
-        item = tarfile.TarInfo(os.path.join(root, dp))
-        # TODO: would be cool to actually set it to the timestamp of the
-        # revision it was last changed
-        item.mtime = now
-        if self.kind == 'directory':
-            item.type = tarfile.DIRTYPE
-            fileobj = None
-            item.name += '/'
-            item.size = 0
-            item.mode = 0755
-        elif self.kind == 'file':
-            item.type = tarfile.REGTYPE
-            fileobj = tree.get_file(self.file_id)
-            item.size = self.text_size
-            if tree.is_executable(self.file_id):
-                item.mode = 0755
-            else:
-                item.mode = 0644
-        else:
-            raise BzrError("don't know how to export {%s} of kind %r" %
-                    (self.file_id, self.kind))
-        return item, fileobj
-
-    def has_text(self):
-        """Return true if the object this entry represents has textual data.
-
-        Note that textual data includes binary content.
-        """
-        if self.kind =='file':
-            return True
-        else:
-            return False
-
     def __init__(self, file_id, name, kind, parent_id, text_id=None):
         """Create an InventoryEntry
         
@@ -268,25 +170,12 @@
             return ''
         raise RuntimeError('unreachable code')
 
-    known_kinds = ('file', 'directory', 'symlink', 'root_directory')
-
-    def put_on_disk(self, dest, dp, tree):
-        """Create a representation of self on disk in the prefix dest."""
-        fullpath = appendpath(dest, dp)
-        if self.kind == 'directory':
-            os.mkdir(fullpath)
-        elif self.kind == 'file':
-            pumpfile(tree.get_file(self.file_id), file(fullpath, 'wb'))
-            if tree.is_executable(self.file_id):
-                os.chmod(fullpath, 0755)
-        elif self.kind == 'symlink':
+    def read_symlink_target(self, path):
+        if self.kind == 'symlink':
             try:
-                os.symlink(self.symlink_target, fullpath)
+                self.symlink_target = os.readlink(path)
             except OSError,e:
-                raise BzrError("Failed to create symlink %r -> %r, error: %s" % (fullpath, self.symlink_target, e))
-        else:
-            raise BzrError("don't know how to export {%s} of kind %r" % (self.file_id, self.kind))
-        mutter("  export {%s} kind %s to %s" % (self.file_id, self.kind, fullpath))
+                raise BzrError("os.readlink error, %s" % e)
 
     def sorted_children(self):
         l = self.children.items()
@@ -454,7 +343,7 @@
 
     def _read_tree_state(self, path, work_tree):
         if self.kind == 'symlink':
-            self.symlink_target = work_tree.get_symlink_target(self.file_id)
+            self.read_symlink_target(work_tree.abspath(path))
         if self.kind == 'file':
             self.text_sha1 = work_tree.get_file_sha1(self.file_id)
             self.executable = work_tree.is_executable(self.file_id)

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2005-10-03 05:16:47 +0000
+++ bzrlib/osutils.py	2005-09-30 02:54:51 +0000
@@ -543,10 +543,3 @@
         if e.errno != errno.EXDEV:
             raise
         copyfile(src, dest)
-
-
-def has_symlinks():
-    if hasattr(os, 'symlink'):
-        return True
-    else:
-        return False

=== modified file 'bzrlib/selftest/blackbox.py'
--- bzrlib/selftest/blackbox.py	2005-10-03 05:16:47 +0000
+++ bzrlib/selftest/blackbox.py	2005-10-02 21:51:29 +0000
@@ -34,7 +34,6 @@
 
 from bzrlib.selftest import TestCaseInTempDir, BzrTestBase
 from bzrlib.branch import Branch
-from bzrlib.osutils import has_symlinks
 
 
 class ExternalBase(TestCaseInTempDir):
@@ -409,6 +408,13 @@
         err.index('unknown command')
         
 
+
+def has_symlinks():
+    if hasattr(os, 'symlink'):
+        return True
+    else:
+        return False
+
 def listdir_sorted(dir):
     L = os.listdir(dir)
     L.sort()

=== modified file 'bzrlib/selftest/testinv.py'
--- bzrlib/selftest/testinv.py	2005-10-03 05:27:22 +0000
+++ bzrlib/selftest/testinv.py	2005-10-03 02:54:29 +0000
@@ -14,14 +14,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-from cStringIO import StringIO
 import os
+from bzrlib.selftest import TestCase, TestCaseInTempDir
 
-from bzrlib.branch import Branch
-from bzrlib.diff import internal_diff
 from bzrlib.inventory import Inventory, InventoryEntry, ROOT_ID
-from bzrlib.osutils import has_symlinks
-from bzrlib.selftest import TestCase, TestCaseInTempDir
 
 
 class TestInventory(TestCase):
@@ -77,144 +73,3 @@
     def test_link_kind_character(self):
         dir = InventoryEntry('123', 'hello.c', 'symlink', ROOT_ID)
         self.assertEqual(dir.kind_character(), '')
-
-    def test_dir_detect_changes(self):
-        left = InventoryEntry('123', 'hello.c', 'directory', ROOT_ID)
-        left.text_sha1 = 123
-        left.executable = True
-        left.symlink_target='foo'
-        right = InventoryEntry('123', 'hello.c', 'directory', ROOT_ID)
-        right.text_sha1 = 321
-        right.symlink_target='bar'
-        self.assertEqual((False, False), left.detect_changes(right))
-        self.assertEqual((False, False), right.detect_changes(left))
-
-    def test_file_detect_changes(self):
-        left = InventoryEntry('123', 'hello.c', 'file', ROOT_ID)
-        left.text_sha1 = 123
-        right = InventoryEntry('123', 'hello.c', 'file', ROOT_ID)
-        right.text_sha1 = 123
-        self.assertEqual((False, False), left.detect_changes(right))
-        self.assertEqual((False, False), right.detect_changes(left))
-        left.executable = True
-        self.assertEqual((False, True), left.detect_changes(right))
-        self.assertEqual((False, True), right.detect_changes(left))
-        right.text_sha1 = 321
-        self.assertEqual((True, True), left.detect_changes(right))
-        self.assertEqual((True, True), right.detect_changes(left))
-
-    def test_symlink_detect_changes(self):
-        left = InventoryEntry('123', 'hello.c', 'symlink', ROOT_ID)
-        left.text_sha1 = 123
-        left.executable = True
-        left.symlink_target='foo'
-        right = InventoryEntry('123', 'hello.c', 'symlink', ROOT_ID)
-        right.text_sha1 = 321
-        right.symlink_target='foo'
-        self.assertEqual((False, False), left.detect_changes(right))
-        self.assertEqual((False, False), right.detect_changes(left))
-        left.symlink_target = 'different'
-        self.assertEqual((True, False), left.detect_changes(right))
-        self.assertEqual((True, False), right.detect_changes(left))
-
-    def test_file_has_text(self):
-        file = InventoryEntry('123', 'hello.c', 'file', ROOT_ID)
-        self.failUnless(file.has_text())
-
-    def test_directory_has_text(self):
-        dir = InventoryEntry('123', 'hello.c', 'directory', ROOT_ID)
-        self.failIf(dir.has_text())
-
-    def test_link_has_text(self):
-        link = InventoryEntry('123', 'hello.c', 'symlink', ROOT_ID)
-        self.failIf(link.has_text())
-
-
-class TestEntryDiffing(TestCaseInTempDir):
-
-    def setUp(self):
-        super(TestEntryDiffing, self).setUp()
-        self.branch = Branch.initialize('.')
-        print >> open('file', 'wb'), 'foo'
-        self.branch.add(['file'], ['fileid'])
-        if has_symlinks():
-            os.symlink('target1', 'symlink')
-            self.branch.add(['symlink'], ['linkid'])
-        self.branch.commit('message_1', rev_id = '1')
-        print >> open('file', 'wb'), 'bar'
-        if has_symlinks():
-            os.unlink('symlink')
-            os.symlink('target2', 'symlink')
-        self.tree_1 = self.branch.revision_tree('1')
-        self.inv_1 = self.branch.get_inventory('1')
-        self.file_1 = self.inv_1['fileid']
-        self.tree_2 = self.branch.working_tree()
-        self.inv_2 = self.branch.inventory
-        self.file_2 = self.inv_2['fileid']
-        if has_symlinks():
-            self.link_1 = self.inv_1['linkid']
-            self.link_2 = self.inv_2['linkid']
-
-    def test_file_diff_deleted(self):
-        output = StringIO()
-        self.file_1.diff(internal_diff, 
-                          "old_label", self.tree_1,
-                          "/dev/null", None, None,
-                          output)
-        self.assertEqual(output.getvalue(), "--- old_label\n"
-                                            "+++ /dev/null\n"
-                                            "@@ -1,1 +0,0 @@\n"
-                                            "-foo\n"
-                                            "\n")
-
-    def test_file_diff_added(self):
-        output = StringIO()
-        self.file_1.diff(internal_diff, 
-                          "new_label", self.tree_1,
-                          "/dev/null", None, None,
-                          output, reverse=True)
-        self.assertEqual(output.getvalue(), "--- /dev/null\n"
-                                            "+++ new_label\n"
-                                            "@@ -0,0 +1,1 @@\n"
-                                            "+foo\n"
-                                            "\n")
-
-    def test_file_diff_changed(self):
-        output = StringIO()
-        self.file_1.diff(internal_diff, 
-                          "/dev/null", self.tree_1, 
-                          "new_label", self.file_2, self.tree_2,
-                          output)
-        self.assertEqual(output.getvalue(), "--- /dev/null\n"
-                                            "+++ new_label\n"
-                                            "@@ -1,1 +1,1 @@\n"
-                                            "-foo\n"
-                                            "+bar\n"
-                                            "\n")
-        
-    def test_link_diff_deleted(self):
-        output = StringIO()
-        self.link_1.diff(internal_diff, 
-                          "old_label", self.tree_1,
-                          "/dev/null", None, None,
-                          output)
-        self.assertEqual(output.getvalue(),
-                         "=== target was 'target1'\n")
-
-    def test_link_diff_added(self):
-        output = StringIO()
-        self.link_1.diff(internal_diff, 
-                          "new_label", self.tree_1,
-                          "/dev/null", None, None,
-                          output, reverse=True)
-        self.assertEqual(output.getvalue(),
-                         "=== target is 'target1'\n")
-
-    def test_link_diff_changed(self):
-        output = StringIO()
-        self.link_1.diff(internal_diff, 
-                          "/dev/null", self.tree_1, 
-                          "new_label", self.link_2, self.tree_2,
-                          output)
-        self.assertEqual(output.getvalue(),
-                         "=== target changed 'target1' => 'target2'\n")

=== modified file 'bzrlib/textinv.py'
--- bzrlib/textinv.py	2005-10-03 05:54:35 +0000
+++ bzrlib/textinv.py	2005-09-26 08:56:15 +0000
@@ -69,6 +69,8 @@
     outf.write(END_MARK)
 
 
+
+
 def read_text_inventory(tf):
     """Return an inventory read in from tf"""
     if tf.readline() != START_MARK:

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2005-10-03 05:54:35 +0000
+++ bzrlib/tree.py	2005-10-03 02:54:29 +0000
@@ -24,7 +24,7 @@
 from bzrlib.trace import mutter, note
 from bzrlib.errors import BzrError, BzrCheckError
 from bzrlib.inventory import Inventory
-from bzrlib.osutils import appendpath, fingerprint_file
+from bzrlib.osutils import pumpfile, appendpath, fingerprint_file
 
 
 exporters = {}
@@ -275,8 +275,22 @@
     mutter('export version %r' % tree)
     inv = tree.inventory
     for dp, ie in inv.iter_entries():
-        ie.put_on_disk(dest, dp, tree)
-
+        kind = ie.kind
+        fullpath = appendpath(dest, dp)
+        if kind == 'directory':
+            os.mkdir(fullpath)
+        elif kind == 'file':
+            pumpfile(tree.get_file(ie.file_id), file(fullpath, 'wb'))
+            if tree.is_executable(ie.file_id):
+                os.chmod(fullpath, 0755)
+        elif kind == 'symlink':
+            try:
+                os.symlink(ie.symlink_target, fullpath)
+            except OSError,e:
+                raise BzrError("Failed to create symlink %r -> %r, error: %s" % (fullpath, ie.symlink_target, e))
+        else:
+            raise BzrError("don't know how to export {%s} of kind %r" % (ie.file_id, kind))
+        mutter("  export {%s} kind %s to %s" % (ie.file_id, kind, fullpath))
 exporters['dir'] = dir_exporter
 
 try:
@@ -325,10 +339,30 @@
         inv = tree.inventory
         for dp, ie in inv.iter_entries():
             mutter("  export {%s} kind %s to %s" % (ie.file_id, ie.kind, dest))
-            item, fileobj = ie.get_tar_item(root, dp, now, tree)
+            item = tarfile.TarInfo(os.path.join(root, dp))
+            # TODO: would be cool to actually set it to the timestamp of the
+            # revision it was last changed
+            item.mtime = now
+            if ie.kind == 'directory':
+                item.type = tarfile.DIRTYPE
+                fileobj = None
+                item.name += '/'
+                item.size = 0
+                item.mode = 0755
+            elif ie.kind == 'file':
+                item.type = tarfile.REGTYPE
+                fileobj = tree.get_file(ie.file_id)
+                item.size = _find_file_size(fileobj)
+                if tree.is_executable(ie.file_id):
+                    item.mode = 0755
+                else:
+                    item.mode = 0644
+            else:
+                raise BzrError("don't know how to export {%s} of kind %r" %
+                        (ie.file_id, ie.kind))
+
             ball.addfile(item, fileobj)
         ball.close()
-
     exporters['tar'] = tar_exporter
 
     def tgz_exporter(tree, dest, root):
@@ -338,3 +372,21 @@
     def tbz_exporter(tree, dest, root):
         tar_exporter(tree, dest, root, compression='bz2')
     exporters['tbz2'] = tbz_exporter
+
+
+def _find_file_size(fileobj):
+    offset = fileobj.tell()
+    try:
+        fileobj.seek(0, 2)
+        size = fileobj.tell()
+    except TypeError:
+        # gzip doesn't accept second argument to seek()
+        fileobj.seek(0)
+        size = 0
+        while True:
+            nread = len(fileobj.read())
+            if nread == 0:
+                break
+            size += nread
+    fileobj.seek(offset)
+    return size

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2005-10-03 05:54:35 +0000
+++ bzrlib/upgrade.py	2005-10-02 21:51:29 +0000
@@ -324,7 +324,7 @@
         for file_id in inv:
             ie = inv[file_id]
             self._set_revision(rev, ie, parent_invs)
-            if not ie.has_text():
+            if ie.kind != 'file':
                 continue
             self._convert_file_version(rev, ie, parent_invs)
 

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2005-10-03 03:30:02 +0000
+++ bzrlib/workingtree.py	2005-10-03 02:54:29 +0000
@@ -37,9 +37,6 @@
     this is a parallel hierarchy to InventoryEntry, and needs to become
     one of several things: decorates to that hierarchy, children of, or
     parents of it.
-    Another note is that these objects are currently only used when there is
-    no InventoryEntry available - i.e. for unversioned objects.
-    Perhaps they should be UnversionedEntry et al. ? - RBC 20051003
     """
  
     def __eq__(self, other):

=== modified file 'bzrlib/xml5.py'
--- bzrlib/xml5.py	2005-10-03 05:54:35 +0000
+++ bzrlib/xml5.py	2005-10-03 01:42:16 +0000
@@ -45,8 +45,7 @@
 
     def _pack_entry(self, ie):
         """Convert InventoryEntry to XML element"""
-        if not InventoryEntry.versionable_kind(ie.kind):
-            raise AssertionError('unsupported entry kind %s' % ie.kind)
+        assert ie.kind in ('directory', 'file', 'symlink')
         e = Element(ie.kind)
         e.set('name', ie.name)
         e.set('file_id', ie.file_id)
@@ -118,7 +117,7 @@
 
     def _unpack_entry(self, elt):
         kind = elt.tag
-        if not InventoryEntry.versionable_kind(kind):
+        if not kind in ('directory', 'file', 'symlink'):
             raise AssertionError('unsupported entry kind %s' % kind)
 
         parent_id = elt.get('parent_id')

